var classboost_1_1locale_1_1localization__backend__manager =
[
    [ "localization_backend_manager", "classboost_1_1locale_1_1localization__backend__manager.html#a0407271db5e7722f901c510474c3581f", null ],
    [ "localization_backend_manager", "classboost_1_1locale_1_1localization__backend__manager.html#ad2fb02931f4b202eedc46b3da4a24449", null ],
    [ "~localization_backend_manager", "classboost_1_1locale_1_1localization__backend__manager.html#a7e602229ef95ea60834fdea95110bf19", null ],
    [ "add_backend", "classboost_1_1locale_1_1localization__backend__manager.html#a7a99faeffb288bddc77995658791c01f", null ],
    [ "adopt_backend", "classboost_1_1locale_1_1localization__backend__manager.html#a500c6b9f43bdaf14b120d4513b51431d", null ],
    [ "create", "classboost_1_1locale_1_1localization__backend__manager.html#add1a6cfabe95e4beabe762f672f30910", null ],
    [ "get_all_backends", "classboost_1_1locale_1_1localization__backend__manager.html#a6c0d5c978d1a77a60f02f4354adedb3a", null ],
    [ "get_unique_ptr", "classboost_1_1locale_1_1localization__backend__manager.html#a52bc196161591ad8edbc22839754161f", null ],
    [ "global", "classboost_1_1locale_1_1localization__backend__manager.html#a65649bc161a0cc160da9b40a9ad14e20", null ],
    [ "global", "classboost_1_1locale_1_1localization__backend__manager.html#a0935a48d3012f62197f4e92119ee62b5", null ],
    [ "operator=", "classboost_1_1locale_1_1localization__backend__manager.html#af506ec1809f2f67c71f590862f63eeab", null ],
    [ "remove_all_backends", "classboost_1_1locale_1_1localization__backend__manager.html#a8c9841c83aa85dbf8f61b2e17732499a", null ],
    [ "select", "classboost_1_1locale_1_1localization__backend__manager.html#adf33775a09e7a765c3401e769019e915", null ]
];